PcmFormat

Struct PcmFormat 

pub struct PcmFormat {
    pub sample_rate_hz: u32,
    pub channels: u8,
    pub sample: SampleFormat,
}
Rate, channel count and sample encoding.

Fields

sample_rate_hz: u32

Frames per second.

channels: u8

Interleaved channels per frame (1 = mono, 2 = stereo).

sample: SampleFormat

Encoding of each channel value.

Implementations

Source

impl PcmFormat

pub const PCM16_16K_MONO: PcmFormat

16 kHz mono 16-bit — the voice default.

pub const PCM16_48K_STEREO: PcmFormat

48 kHz stereo 16-bit — the media default.

pub const fn new( sample_rate_hz: u32, channels: u8, sample: SampleFormat, ) -> Result<PcmFormat, Error>

Build a format, rejecting a zero rate or zero channels.

pub const fn frame_bytes(&self) -> usize

Bytes per sample frame (all channels).

pub const fn bytes_for_micros(&self, micros: u64) -> usize

Bytes needed to hold micros of audio, rounded down to a whole frame.

pub const fn micros_for_frames(&self, frames: usize) -> u64

Duration in microseconds of frames sample frames.